@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -40,7 +40,7 @@
 #include <glib/gi18n.h>
 #include <dbus/dbus-glib.h>
 #include <gconf/gconf-client.h>
-#include <devkit-power-gobject/devicekit-power.h>
+#include <libupower-glib/upower.h>
 
 #include "gpm-button.h"
 #include "gpm-backlight.h"
@@ -48,18 +48,18 @@
 #include "gpm-control.h"
 #include "gpm-common.h"
 #include "egg-debug.h"
-#include "gpm-popup-window.h"
+#include "gsd-media-keys-window.h"
 #include "gpm-dpms.h"
 #include "gpm-idle.h"
 #include "gpm-marshal.h"
 #include "gpm-stock-icons.h"
-#include "gpm-prefs-server.h"
+#include "egg-console-kit.h"
 
 #define GPM_BACKLIGHT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_BACKLIGHT, GpmBacklightPrivate))
 
 struct GpmBacklightPrivate
 {
-	DkpClient		*client;
+	UpClient		*client;
 	GpmBrightness		*brightness;
 	GpmButton		*button;
 	GConfClient		*conf;
@@ -67,6 +67,7 @@ struct GpmBacklightPrivate
 	GpmControl		*control;
 	GpmDpms			*dpms;
 	GpmIdle			*idle;
+	EggConsoleKit		*consolekit;
 	gboolean		 can_dim;
 	gboolean		 system_is_idle;
 	GTimer			*idle_timer;
@@ -110,7 +111,7 @@ gpm_backlight_get_brightness (GpmBacklight *backlight, guint *brightness, GError
 
 	/* check if we have the hw */
 	if (backlight->priv->can_dim == FALSE) {
-		*error = g_error_new (gpm_backlight_error_quark (),
+		g_set_error_literal (error, gpm_backlight_error_quark (),
 				      GPM_BACKLIGHT_ERROR_HARDWARE_NOT_PRESENT,
 				      "Dim capable hardware not present");
 		return FALSE;
@@ -121,7 +122,7 @@ gpm_backlight_get_brightness (GpmBacklight *backlight, guint *brightness, GError
 	if (ret) {
 		*brightness = level;
 	} else {
-		*error = g_error_new (gpm_backlight_error_quark (),
+		g_set_error_literal (error, gpm_backlight_error_quark (),
 				      GPM_BACKLIGHT_ERROR_DATA_NOT_AVAILABLE,
 				      "Data not available");
 	}
@@ -142,7 +143,7 @@ gpm_backlight_set_brightness (GpmBacklight *backlight, guint percentage, GError
 
 	/* check if we have the hw */
 	if (backlight->priv->can_dim == FALSE) {
-		*error = g_error_new (gpm_backlight_error_quark (),
+		g_set_error_literal (error, gpm_backlight_error_quark (),
 				      GPM_BACKLIGHT_ERROR_HARDWARE_NOT_PRESENT,
 				      "Dim capable hardware not present");
 		return FALSE;
@@ -154,7 +155,7 @@ gpm_backlight_set_brightness (GpmBacklight *backlight, guint percentage, GError
 	/* sets the current policy brightness */
 	ret = gpm_brightness_set (backlight->priv->brightness, percentage, &hw_changed);
 	if (!ret) {
-		*error = g_error_new (gpm_backlight_error_quark (),
+		g_set_error_literal (error, gpm_backlight_error_quark (),
 				      GPM_BACKLIGHT_ERROR_GENERAL,
 				      "Cannot set policy brightness");
 	}
@@ -166,6 +167,92 @@ gpm_backlight_set_brightness (GpmBacklight *backlight, guint percentage, GError
 	return ret;
 }
 
+/**
+ * gpm_backlight_dialog_init:
+ *
+ * Initialises the popup, and makes sure that it matches the compositing of the screen.
+ **/
+static void
+gpm_backlight_dialog_init (GpmBacklight *backlight)
+{
+	if (backlight->priv->popup != NULL
+	    && !gsd_media_keys_window_is_valid (GSD_MEDIA_KEYS_WINDOW (backlight->priv->popup))) {
+		gtk_widget_destroy (backlight->priv->popup);
+		backlight->priv->popup = NULL;
+	}
+
+	if (backlight->priv->popup == NULL) {
+		backlight->priv->popup= gsd_media_keys_window_new ();
+		gsd_media_keys_window_set_action_custom (GSD_MEDIA_KEYS_WINDOW (backlight->priv->popup),
+							 "gpm-brightness-lcd",
+							 TRUE);
+		gtk_window_set_position (GTK_WINDOW (backlight->priv->popup), GTK_WIN_POS_NONE);
+	}
+}
+
+/**
+ * gpm_backlight_dialog_show:
+ *
+ * Show the brightness popup, and place it nicely on the screen.
+ **/
+static void
+gpm_backlight_dialog_show (GpmBacklight *backlight)
+{
+	int            orig_w;
+	int            orig_h;
+	int            screen_w;
+	int            screen_h;
+	int            x;
+	int            y;
+	int            pointer_x;
+	int            pointer_y;
+	GtkRequisition win_req;
+	GdkScreen     *pointer_screen;
+	GdkRectangle   geometry;
+	int            monitor;
+
+	/*
+	 * get the window size
+	 * if the window hasn't been mapped, it doesn't necessarily
+	 * know its true size, yet, so we need to jump through hoops
+	 */
+	gtk_window_get_default_size (GTK_WINDOW (backlight->priv->popup), &orig_w, &orig_h);
+	gtk_widget_size_request (backlight->priv->popup, &win_req);
+
+	if (win_req.width > orig_w) {
+		orig_w = win_req.width;
+	}
+	if (win_req.height > orig_h) {
+		orig_h = win_req.height;
+	}
+
+	pointer_screen = NULL;
+	gdk_display_get_pointer (gtk_widget_get_display (backlight->priv->popup),
+				 &pointer_screen,
+				 &pointer_x,
+				 &pointer_y,
+				 NULL);
+	monitor = gdk_screen_get_monitor_at_point (pointer_screen,
+						   pointer_x,
+						   pointer_y);
+
+	gdk_screen_get_monitor_geometry (pointer_screen,
+					 monitor,
+					 &geometry);
+
+	screen_w = geometry.width;
+	screen_h = geometry.height;
+
+	x = ((screen_w - orig_w) / 2) + geometry.x;
+	y = geometry.y + (screen_h / 2) + (screen_h / 2 - orig_h) / 2;
+
+	gtk_window_move (GTK_WINDOW (backlight->priv->popup), x, y);
+
+	gtk_widget_show (backlight->priv->popup);
+
+	gdk_display_sync (gtk_widget_get_display (backlight->priv->popup));
+}
+
 /**
  * gpm_common_sum_scale:
  *
@@ -261,8 +348,10 @@ gpm_backlight_brightness_evaluate_and_set (GpmBacklight *backlight, gboolean int
 
 	/* only show dialog if interactive */
 	if (interactive) {
-		gpm_popup_window_set_value (GPM_POPUP_WINDOW (backlight->priv->popup), (float) brightness);
-		gtk_widget_show (backlight->priv->popup);
+		gpm_backlight_dialog_init (backlight);
+		gsd_media_keys_window_set_volume_level (GSD_MEDIA_KEYS_WINDOW (backlight->priv->popup),
+							round (brightness));
+		gpm_backlight_dialog_show (backlight);
 	}
 
 	ret = gpm_brightness_set (backlight->priv->brightness, value, &hw_changed);
@@ -318,13 +407,13 @@ gpm_conf_gconf_key_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *e
 
 /**
  * gpm_backlight_client_changed_cb:
- * @client: The dkp_client class instance
+ * @client: The up_client class instance
  * @backlight: This class instance
  *
  * Does the actions when the ac power source is inserted/removed.
  **/
 static void
-gpm_backlight_client_changed_cb (DkpClient *client, GpmBacklight *backlight)
+gpm_backlight_client_changed_cb (UpClient *client, GpmBacklight *backlight)
 {
 	gpm_backlight_brightness_evaluate_and_set (backlight, FALSE);
 }
@@ -352,8 +441,10 @@ gpm_backlight_button_pressed_cb (GpmButton *button, const gchar *type, GpmBackli
 		/* show the new value */
 		if (ret) {
 			gpm_brightness_get (backlight->priv->brightness, &percentage);
-			gpm_popup_window_set_value (GPM_POPUP_WINDOW (backlight->priv->popup), (gfloat) percentage/100.0f);
-			gtk_widget_show (backlight->priv->popup);
+			gpm_backlight_dialog_init (backlight);
+			gsd_media_keys_window_set_volume_level (GSD_MEDIA_KEYS_WINDOW (backlight->priv->popup),
+								percentage);
+			gpm_backlight_dialog_show (backlight);
 			/* save the new percentage */
 			backlight->priv->master_percentage = percentage;
 		}
@@ -369,8 +460,10 @@ gpm_backlight_button_pressed_cb (GpmButton *button, const gchar *type, GpmBackli
 		/* show the new value */
 		if (ret) {
 			gpm_brightness_get (backlight->priv->brightness, &percentage);
-			gpm_popup_window_set_value (GPM_POPUP_WINDOW (backlight->priv->popup), (gfloat) percentage/100.0f);
-			gtk_widget_show (backlight->priv->popup);
+			gpm_backlight_dialog_init (backlight);
+			gsd_media_keys_window_set_volume_level (GSD_MEDIA_KEYS_WINDOW (backlight->priv->popup),
+								percentage);
+			gpm_backlight_dialog_show (backlight);
 			/* save the new percentage */
 			backlight->priv->master_percentage = percentage;
 		}
@@ -465,6 +558,12 @@ idle_changed_cb (GpmIdle *idle, GpmIdleMode mode, GpmBacklight *backlight)
 	if (gpm_button_is_lid_closed (backlight->priv->button))
 		return;
 
+	/* don't dim or undim the screen unless we are on the active console */
+	if (!egg_console_kit_is_active (backlight->priv->consolekit)) {
+		egg_debug ("ignoring as not on active console");
+		return;
+	}
+
 	if (mode == GPM_IDLE_MODE_NORMAL) {
 		/* sync lcd brightness */
 		gpm_backlight_notify_system_idle_changed (backlight, FALSE);
@@ -586,6 +685,7 @@ gpm_backlight_finalize (GObject *object)
 	g_object_unref (backlight->priv->button);
 	g_object_unref (backlight->priv->idle);
 	g_object_unref (backlight->priv->brightness);
+	g_object_unref (backlight->priv->consolekit);
 
 	g_return_if_fail (backlight->priv != NULL);
 	G_OBJECT_CLASS (gpm_backlight_parent_class)->finalize (object);
@@ -623,9 +723,6 @@ gpm_backlight_class_init (GpmBacklightClass *klass)
 static void
 gpm_backlight_init (GpmBacklight *backlight)
 {
-	gboolean lid_is_present = TRUE;
-	GpmPrefsServer *prefs_server;
-
 	backlight->priv = GPM_BACKLIGHT_GET_PRIVATE (backlight);
 
 	/* record our idle time */
@@ -636,29 +733,14 @@ gpm_backlight_init (GpmBacklight *backlight)
 	g_signal_connect (backlight->priv->brightness, "brightness-changed",
 			  G_CALLBACK (brightness_changed_cb), backlight);
 
-	/* we use dkp_client for the ac-adapter-changed signal */
-	backlight->priv->client = dkp_client_new ();
+	/* we use up_client for the ac-adapter-changed signal */
+	backlight->priv->client = up_client_new ();
 	g_signal_connect (backlight->priv->client, "changed",
 			  G_CALLBACK (gpm_backlight_client_changed_cb), backlight);
 
 	/* gets caps */
 	backlight->priv->can_dim = gpm_brightness_has_hw (backlight->priv->brightness);
 
-	/* we use DeviceKit-power to see if we should show the lid UI */
-#if DKP_CHECK_VERSION(0x009)
-	g_object_get (backlight->priv->client,
-		      "lid-is-present", &lid_is_present,
-		      NULL);
-#endif
-
-	/* expose ui in prefs program */
-	prefs_server = gpm_prefs_server_new ();
-	if (lid_is_present)
-		gpm_prefs_server_set_capability (prefs_server, GPM_PREFS_SERVER_LID);
-	if (backlight->priv->can_dim)
-		gpm_prefs_server_set_capability (prefs_server, GPM_PREFS_SERVER_BACKLIGHT);
-	g_object_unref (prefs_server);
-
 	/* watch for dim value changes */
 	backlight->priv->conf = gconf_client_get_default ();
 
@@ -688,10 +770,11 @@ gpm_backlight_init (GpmBacklight *backlight)
 	gpm_idle_set_timeout_dim (backlight->priv->idle, backlight->priv->idle_dim_timeout);
 
 	/* use a visual widget */
-	backlight->priv->popup = gpm_popup_window_new ();
+	backlight->priv->popup = gsd_media_keys_window_new ();
+	gsd_media_keys_window_set_action_custom (GSD_MEDIA_KEYS_WINDOW (backlight->priv->popup),
+						 "gpm-brightness-lcd",
+						 TRUE);
         gtk_window_set_position (GTK_WINDOW (backlight->priv->popup), GTK_WIN_POS_NONE);
-	gpm_popup_window_set_icon_name (GPM_POPUP_WINDOW (backlight->priv->popup),
-					GPM_STOCK_BRIGHTNESS_LCD);
 
 	/* DPMS mode poll class */
 	backlight->priv->dpms = gpm_dpms_new ();
@@ -701,6 +784,9 @@ gpm_backlight_init (GpmBacklight *backlight)
 	g_signal_connect (backlight->priv->control, "resume",
 			  G_CALLBACK (control_resume_cb), backlight);
 
+	/* Don't do dimming on inactive console */
+	backlight->priv->consolekit = egg_console_kit_new ();
+
 	/* sync at startup */
 	gpm_backlight_brightness_evaluate_and_set (backlight, FALSE);
 }
