@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -29,7 +29,7 @@
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 #include <X11/XF86keysym.h>
-#include <devkit-power-gobject/devicekit-power.h>
+#include <libupower-glib/upower.h>
 
 #include "gpm-common.h"
 #include "gpm-button.h"
@@ -48,7 +48,7 @@ struct GpmButtonPrivate
 	gchar			*last_button;
 	GTimer			*timer;
 	gboolean		 lid_is_closed;
-	DkpClient		*client;
+	UpClient		*client;
 };
 
 enum {
@@ -255,8 +255,14 @@ gpm_button_class_init (GpmButtonClass *klass)
 gboolean
 gpm_button_is_lid_closed (GpmButton *button)
 {
+	gboolean lid_is_closed;
+
 	g_return_val_if_fail (GPM_IS_BUTTON (button), FALSE);
-	return button->priv->lid_is_closed;
+
+	g_object_get (button->priv->client,
+		      "lid-is-closed", &lid_is_closed,
+		      NULL);
+	return lid_is_closed;
 }
 
 /**
@@ -277,7 +283,7 @@ gpm_button_reset_time (GpmButton *button)
  * gpm_button_client_changed_cb
  **/
 static void
-gpm_button_client_changed_cb (DkpClient *client, GpmButton *button)
+gpm_button_client_changed_cb (UpClient *client, GpmButton *button)
 {
 	gboolean lid_is_closed;
 
@@ -317,7 +323,7 @@ gpm_button_init (GpmButton *button)
 	button->priv->timer = g_timer_new ();
 
 	button->priv->lid_is_closed = FALSE;
-	button->priv->client = dkp_client_new ();
+	button->priv->client = up_client_new ();
 	g_signal_connect (button->priv->client, "changed",
 			  G_CALLBACK (gpm_button_client_changed_cb), button);
 
